@@ -35,23 +35,21 @@ Connects to XML RPC server and runs arbitrary functions.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.5'
+__version__ = '0.6'
 
 
 import os
+import sys
 import xmlrpclib
 import cli_common_lib
 
 
-SERVER_NAME = u'https://localhost:8000'
-
-
 class InvalidCredentials(Exception):
   pass
 
 
 def RunFunction(function, user_name, credfile=None, credstring=None,
-                args=[], kwargs={}, server_name=SERVER_NAME,
+                args=[], kwargs={}, server_name=None,
                 raise_errors=False):
   """Runs an arbitrary function for SERVER
 
@@ -67,14 +65,16 @@ def RunFunction(function, user_name, credfile=None, credstring=None,
     return from function in core
   """
   if( credfile is None ):
-    credfile = os.path.join('.dnscred', os.path.expanduser('~'))
+    credfile = os.path.expanduser('~/.dnscred')
+  else:
+    credfile = os.path.expanduser(credfile)
   server = xmlrpclib.ServerProxy(server_name, allow_none=True)
   ## Read credential File
   core_return = ''
   if( credstring is None ):
     if( os.path.exists(credfile) ):
+      credfile_handle = open(credfile, 'r')
       try:
-        credfile_handle = open(credfile, 'r')
         credstring = str(credfile_handle.read()).strip('\n')
         credfile_handle.close()
       except OSError:
@@ -83,25 +83,29 @@ def RunFunction(function, user_name, credfile=None, credstring=None,
       raise InvalidCredentials('Credential file not found.')
   try:
     core_return = server.CoreRun(function, user_name, credstring, args, kwargs)
-  except xmlrpclib.Fault, error:
-    error_type = eval(error.faultString.split('>:')[0].strip('<class '))
-    error_string = error.faultString.split('>:')[1]
-    if( error_type == '_mysql_exceptions.IntegrityError' ):
-      ## Can detect other certain cases of error_type later if needed
-      error_string = eval(error_string)[1] # [0] is error code
+  except xmlrpclib.Fault, e:
     if( raise_errors ):
       raise
-    else:
-      cli_common_lib.ServerError(error_string, 1)
+    print "SERVER ERROR: %s" % e.faultString
+    sys.exit(1)
+
 
   if( core_return == 'ERROR: Invalid Credentials' ):
     raise InvalidCredentials('Credential file is invalid.')
+  elif( core_return['new_credential'] is not None and
+        core_return['new_credential'] != '' ):
+    if( os.path.exists(credfile) ):
+      credfile_handle = open(credfile, 'w')
+      try:
+        credfile_handle.writelines(core_return['new_credential'])
+      finally:
+        credfile_handle.close()
 
   return core_return
 
 
 def GetCredentials(user_name, password, credfile=None,
-                   server_name=SERVER_NAME):
+                   server_name=None):
   """Gets credential string from CredCache.
 
   Inputs:
@@ -117,6 +121,7 @@ def GetCredentials(user_name, password, credfile=None,
   """
   server = xmlrpclib.ServerProxy(server_name, allow_none=True)
   credential = server.GetCredentials(user_name, password)
+  credfile = os.path.expanduser(credfile)
   if( credfile is not None ):
     try:
       credfile_handle = open(credfile, 'w')
@@ -133,7 +138,7 @@ def GetCredentials(user_name, password, credfile=None,
 
 
 def IsAuthenticated(user_name, credfile,
-                    server_name=SERVER_NAME):
+                    server_name=None):
   """Checks credential file if it is valid.
 
   Inputs:
@@ -144,6 +149,7 @@ def IsAuthenticated(user_name, credfile,
   Outputs:
     bool: whether or not credential file is valid
   """
+  credfile = os.path.expanduser(credfile)
   if( os.path.exists(credfile) ):
     try:
       credfile_handle = open(credfile, 'r')
